==> fuel-ui-0.4.1-3.tgz: package/esm/components/TableSortable/TableSortable.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule, Component, Input } from "@angular/core";
import { CommonModule, JsonPipe } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuiOrderByPipeModule } from "../../pipes/orderBy/orderBy";
import { FuiFormatPipeModule } from "../../pipes/format/format";
import { TableSortableSorting } from "./tableSortableSorting";
export let TableSortable = class TableSortable {
    constructor() {
    }
    selectedClass(column) {
        if (!column.sortable)
            return 'fuel-ui-not-sortable';
        return column.variable == this.sort.column ? 'sort-' + (this.sort.descending ? 'desc' : 'asc') : '';
    }
    changeSorting(column) {
        if (!column.sortable)
            return;
        var sort = this.sort;
        if (sort.column == column.variable) {
            sort.descending = !sort.descending;
        }
        else {
            sort.column = column.variable;
            sort.descending = false;
        }
    }
    convertSorting() {
        return this.sort.descending ? '-' + this.sort.column : this.sort.column;
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Array)
], TableSortable.prototype, "columns", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Array)
], TableSortable.prototype, "data", void 0);
__decorate([
    Input(), 
    __metadata('design:type', TableSortableSorting)
], TableSortable.prototype, "sort", void 0);
TableSortable = __decorate([
    Component({
        selector: 'table-sortable',
        template: "\n    <div class=\"table-responsive\">\n      <table class=\"table table-bordered table-hover table-striped fuel-ui-table-sortable\">\n        <thead>\n          <tr>\n            <th *ngFor=\"let column of columns\" [class]=\"selectedClass(column)\" (click)=\"changeSorting(column)\">\n              {{column.display}}\n            </th>\n          </tr>\n        </thead>\n        <tbody>\n          <tr *ngFor=\"let object of data | orderBy : convertSorting()\">\n            <td *ngFor=\"let column of columns\" [innerHtml]=\"object[column.variable] | format : column.filter\"></td>\n          </tr>\n        </tbody>\n      </table>\n    </div>\n  ",
        pipes: [JsonPipe]
    }), 
    __metadata('design:paramtypes', [])
], TableSortable);
export { TableSortableColumn } from "./TableSortableColumn";
export { TableSortableSorting } from "./TableSortableSorting";
export let FuiTableSortableModule = class FuiTableSortableModule {
};
FuiTableSortableModule = __decorate([
    NgModule({
        imports: [CommonModule, FormsModule, FuiFormatPipeModule, FuiOrderByPipeModule],
        declarations: [TableSortable],
        exports: [TableSortable]
    }), 
    __metadata('design:paramtypes', [])
], FuiTableSortableModule);

==> fuel-ui-0.4.1-4.tgz: package/esm/components/TableSortable/TableSortable.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule, Component, Input } from "@angular/core";
import { CommonModule, JsonPipe } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuiOrderByPipeModule } from "../../pipes/OrderBy/OrderBy";
import { FuiFormatPipeModule } from "../../pipes/Format/Format";
import { TableSortableSorting } from "./TableSortableSorting";
export let TableSortable = class TableSortable {
    constructor() {
    }
    selectedClass(column) {
        if (!column.sortable)
            return 'fuel-ui-not-sortable';
        return column.variable == this.sort.column ? 'sort-' + (this.sort.descending ? 'desc' : 'asc') : '';
    }
    changeSorting(column) {
        if (!column.sortable)
            return;
        var sort = this.sort;
        if (sort.column == column.variable) {
            sort.descending = !sort.descending;
        }
        else {
            sort.column = column.variable;
            sort.descending = false;
        }
    }
    convertSorting() {
        return this.sort.descending ? '-' + this.sort.column : this.sort.column;
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Array)
], TableSortable.prototype, "columns", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Array)
], TableSortable.prototype, "data", void 0);
__decorate([
    Input(), 
    __metadata('design:type', TableSortableSorting)
], TableSortable.prototype, "sort", void 0);
TableSortable = __decorate([
    Component({
        selector: 'table-sortable',
        template: "\n    <div class=\"table-responsive\">\n      <table class=\"table table-bordered table-hover table-striped fuel-ui-table-sortable\">\n        <thead>\n          <tr>\n            <th *ngFor=\"let column of columns\" [class]=\"selectedClass(column)\" (click)=\"changeSorting(column)\">\n              {{column.display}}\n            </th>\n          </tr>\n        </thead>\n        <tbody>\n          <tr *ngFor=\"let object of data | orderBy : convertSorting()\">\n            <td *ngFor=\"let column of columns\" [innerHtml]=\"object[column.variable] | format : column.filter\"></td>\n          </tr>\n        </tbody>\n      </table>\n    </div>\n  ",
        pipes: [JsonPipe]
    }), 
    __metadata('design:paramtypes', [])
], TableSortable);
export { TableSortableColumn } from "./TableSortableColumn";
export { TableSortableSorting } from "./TableSortableSorting";
export let FuiTableSortableModule = class FuiTableSortableModule {
};
FuiTableSortableModule = __decorate([
    NgModule({
        imports: [CommonModule, FormsModule, FuiFormatPipeModule, FuiOrderByPipeModule],
        declarations: [TableSortable],
        exports: [TableSortable]
    }), 
    __metadata('design:paramtypes', [])
], FuiTableSortableModule);
